@@ -9,7 +9,7 @@ def createCodePipelineArtifact():
     artifact = codepipeline.Artifact()
     return artifact
 
-def createCodePipeline(self, codepipeline_name, source_action, build_action, deploy_action=None):
+def createCodePipeline(self, codepipeline_name, codepipeline_role, source_action, build_action, deploy_action=None):
     stages = []
     stages.append(codepipeline.StageProps(stage_name="Source", actions=[source_action]))
     stages.append(codepipeline.StageProps(stage_name="Build", actions=[build_action]))
@@ -19,6 +19,7 @@ def createCodePipeline(self, codepipeline_name, source_action, build_action, dep
     pipeline = codepipeline.Pipeline(
         self, "CDK-CodePipeline-{}".format(codepipeline_name),
         pipeline_name="{}".format(codepipeline_name), 
-        stages=stages, 
+        role=codepipeline_role,
+        stages=stages,
     ) 
     return pipeline
\ No newline at end of file
