@@ -31,7 +31,7 @@ class NotificationStack(Stack):
 
             # the properties below are optional
             bundle_id=apns_bundle_id,
-            certificate=apns_certificate.get_certificate(),
+            # certificate=apns_certificate.get_certificate(),
             default_authentication_method="certificate",
             enabled=True,
             private_key=apns_certificate.get_privatekey(),
